# Earlybyte mission, vision, and values

This tool helps us to remind the mission, vision, and value statement of Earlybyte.

### Installation

To run this tool Python 3.7 is required.

You might need to upgread your pip environment first before installing earlybyte-mvv.

```shell
pip install --upgrade pip
```

The tool can then be installed using the following command:

```shell
pip install earlybyte-mvv
```

### Usage

The tool can be used as follows:

```shell
# print the mission statement of earlybyte
earlybyte mission

# print the vision statement of earlybyte
earlybyte vision

# print all values of earlybyte
earlybyte values

# print a specific value of earlybyte [use 0-4]
earlybyte values 2
```

### About Earlybyte

Earlybyte GmbH is a software company from Winterthur Switzerland. We build IoT, mobile and web applications and solutions that help freeing up time for what really matters.

Find us under https://earlybyte.ch/
